Structs
- Basic
Block - A
BasicBlockis a sequence of zero or more non-terminator instructions followed by a single terminator instruction which ends the block. Basic blocks are discussed in the LLVM 14 docs on Functions
BasicBlock is a sequence of zero or more non-terminator instructions
followed by a single terminator instruction which ends the block.
Basic blocks are discussed in the LLVM 14 docs on Functions