FloatPredicate

Enum FloatPredicate 

pub enum FloatPredicate {
Show 16 variants False, Oeq, Ogt, Oge, Olt, Ole, One, Ord, Uno, Ueq, Ugt, Uge, Ult, Ule, Une, True,
}
Public API for FloatPredicate.

Variants



False

False variant.



Oeq

Oeq variant.



Ogt

Ogt variant.



Oge

Oge variant.



Olt

Olt variant.



Ole

Ole variant.



One

One variant.



Ord

Ord variant.



Uno

Uno variant.



Ueq

Ueq variant.



Ugt

Ugt variant.



Uge

Uge variant.



Ult

Ult variant.



Ule

Ule variant.



Une

Une variant.



True

True variant.

Implementations

Source

impl FloatPredicate

pub fn as_str(self) -> &'static str

Public API for as_str.