Struct llvm_ir::types::Types [−][src]
pub struct Types { /* fields omitted */ }Expand description
Holds a reference to all of the Types used in the Module, and facilitates
lookups so you can get a TypeRef to the Type you want.
Implementations
Get the type of anything that is Typed
Get a pointer type in the default address space (0)
Get a pointer type in the specified address space
Get a function type
Get a struct type
Get the TypeRef for the struct with the given name.
Note that this gives a NamedStructType.
To get the actual definition of a named struct (the NamedStructDef),
use named_struct_def().
Get the NamedStructDef for the struct with the given name, or
None if there is no struct by that name.
Note that this gives a NamedStructDef.
To get the NamedStructType for a name, use named_struct().
Get the names of all the named structs
Add the given NamedStructDef as the definition of the struct with the given name.
Panics if that name already had a definition.
Remove the definition of the struct with the given name.
Returns true if the definition was removed, or false if no definition
existed.
Get the metadata type
Get the label type
Get the token type
Get a TypeRef for the given Type
Get a blank Types containing essentially no types.
This function is intended only for use in testing;
it’s probably not useful otherwise.